==> dif-database-repository-2.1.7-24-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/Acl.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * Acl
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class Acl extends AbstractBeanAttributes implements java.io.Serializable {

    /** Acl attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** userId column */
        public static final String USERID = "userId";
        /** groupId column */
        public static final String GROUPID = "groupId";
        /** entityType column */
        public static final String ENTITYTYPE = "entityType";
        /** entityId column */
        public static final String ENTITYID = "entityId";
        /** publicAccess column */
        public static final String PUBLICACCESS = "publicAccess";
        /** isEnabled column */
        public static final String ISENABLED = "isEnabled";
        /** isDefault column */
        public static final String ISDEFAULT = "isDefault";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("userId");
            list.add("groupId");
            list.add("entityType");
            list.add("entityId");
            list.add("publicAccess");
            list.add("isEnabled");
            list.add("isDefault");

            return list;
        }
    }

    /** Acl FK class */
    public static class FK {
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("userId".equalsIgnoreCase(attributeName))
            return userId;
        if ("groupId".equalsIgnoreCase(attributeName))
            return groupId;
        if ("entityType".equalsIgnoreCase(attributeName))
            return entityType;
        if ("entityId".equalsIgnoreCase(attributeName))
            return entityId;
        if ("publicAccess".equalsIgnoreCase(attributeName))
            return publicAccess;
        if ("isEnabled".equalsIgnoreCase(attributeName))
            return isEnabled;
        if ("isDefault".equalsIgnoreCase(attributeName))
            return isDefault;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("userId".equalsIgnoreCase(attributeName))
            userId = (String)attributeValue;
        if ("groupId".equalsIgnoreCase(attributeName))
            groupId = (String)attributeValue;
        if ("entityType".equalsIgnoreCase(attributeName))
            entityType = (String)attributeValue;
        if ("entityId".equalsIgnoreCase(attributeName))
            entityId = (String)attributeValue;
        if ("publicAccess".equalsIgnoreCase(attributeName))
            publicAccess = (String)attributeValue;
        if ("isEnabled".equalsIgnoreCase(attributeName))
            isEnabled = (String)attributeValue;
        if ("isDefault".equalsIgnoreCase(attributeName))
            isDefault = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** userId private attribute */
    private String userId;

    /** groupId private attribute */
    private String groupId;

    /** entityType private attribute */
    private String entityType;

    /** entityId private attribute */
    private String entityId;

    /** publicAccess private attribute */
    private String publicAccess;

    /** isEnabled private attribute */
    private String isEnabled;

    /** isDefault private attribute */
    private String isDefault;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public Acl() {
    }


    /**
     * full constructor
	 *
     * @param userId
     * @param groupId
     * @param entityType
     * @param entityId
     * @param publicAccess
     * @param isEnabled
     * @param isDefault
     */
    public Acl(String userId, String groupId, String entityType, String entityId, String publicAccess, String isEnabled, String isDefault) {
        this.userId = userId;
        this.groupId = groupId;
        this.entityType = entityType;
        this.entityId = entityId;
        this.publicAccess = publicAccess;
        this.isEnabled = isEnabled;
        this.isDefault = isDefault;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return Acl modified instance
     */
    public Acl setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * userId getter method
     *
     * @return userId method
     */
    public String getUserId() {
        return this.userId;
    }
    
    /**       
     * userId setter method
     *
     * @param userId
     *
     * @return Acl modified instance
     */
    public Acl setUserId(String userId) {
        this.userId = userId;
        
        return this;
    }
    /**       
     * groupId getter method
     *
     * @return groupId method
     */
    public String getGroupId() {
        return this.groupId;
    }
    
    /**       
     * groupId setter method
     *
     * @param groupId
     *
     * @return Acl modified instance
     */
    public Acl setGroupId(String groupId) {
        this.groupId = groupId;
        
        return this;
    }
    /**       
     * entityType getter method
     *
     * @return entityType method
     */
    public String getEntityType() {
        return this.entityType;
    }
    
    /**       
     * entityType setter method
     *
     * @param entityType
     *
     * @return Acl modified instance
     */
    public Acl setEntityType(String entityType) {
        this.entityType = entityType;
        
        return this;
    }
    /**       
     * entityId getter method
     *
     * @return entityId method
     */
    public String getEntityId() {
        return this.entityId;
    }
    
    /**       
     * entityId setter method
     *
     * @param entityId
     *
     * @return Acl modified instance
     */
    public Acl setEntityId(String entityId) {
        this.entityId = entityId;
        
        return this;
    }
    /**       
     * publicAccess getter method
     *
     * @return publicAccess method
     */
    public String getPublicAccess() {
        return this.publicAccess;
    }
    
    /**       
     * publicAccess setter method
     *
     * @param publicAccess
     *
     * @return Acl modified instance
     */
    public Acl setPublicAccess(String publicAccess) {
        this.publicAccess = publicAccess;
        
        return this;
    }
    /**       
     * isEnabled getter method
     *
     * @return isEnabled method
     */
    public String getIsEnabled() {
        return this.isEnabled;
    }
    
    /**       
     * isEnabled setter method
     *
     * @param isEnabled
     *
     * @return Acl modified instance
     */
    public Acl setIsEnabled(String isEnabled) {
        this.isEnabled = isEnabled;
        
        return this;
    }
    /**       
     * isDefault getter method
     *
     * @return isDefault method
     */
    public String getIsDefault() {
        return this.isDefault;
    }
    
    /**       
     * isDefault setter method
     *
     * @param isDefault
     *
     * @return Acl modified instance
     */
    public Acl setIsDefault(String isDefault) {
        this.isDefault = isDefault;
        
        return this;
    }

    /**
     * Creates a String representation of the Acl object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("userId").append("='").append(getUserId()).append("' ");			
        buffer.append("groupId").append("='").append(getGroupId()).append("' ");			
        buffer.append("entityType").append("='").append(getEntityType()).append("' ");			
        buffer.append("entityId").append("='").append(getEntityId()).append("' ");			
        buffer.append("publicAccess").append("='").append(getPublicAccess()).append("' ");			
        buffer.append("isEnabled").append("='").append(getIsEnabled()).append("' ");			
        buffer.append("isDefault").append("='").append(getIsDefault()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the Acl object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(Acl other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("userId".equalsIgnoreCase(attributeName))
        	this.userId = attributeValue;

        if ("groupId".equalsIgnoreCase(attributeName))
        	this.groupId = attributeValue;

        if ("entityType".equalsIgnoreCase(attributeName))
        	this.entityType = attributeValue;

        if ("entityId".equalsIgnoreCase(attributeName))
        	this.entityId = attributeValue;

        if ("publicAccess".equalsIgnoreCase(attributeName))
        	this.publicAccess = attributeValue;

        if ("isEnabled".equalsIgnoreCase(attributeName))
        	this.isEnabled = attributeValue;

        if ("isDefault".equalsIgnoreCase(attributeName))
        	this.isDefault = attributeValue;

    }


}

==> dif-database-repository-2.1.9-12-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/Acl.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * Acl Generated on ORM Generator DIF build process for the Model layer
 */
@SuppressWarnings("serial")
public class Acl extends AbstractBeanAttributes implements java.io.Serializable {

    /** Acl attributes enumeration */
    public static class Fields {

        /** id column */
        public static final String ID = "id";
        /** userId column */
        public static final String USERID = "userId";
        /** groupId column */
        public static final String GROUPID = "groupId";
        /** entityType column */
        public static final String ENTITYTYPE = "entityType";
        /** entityId column */
        public static final String ENTITYID = "entityId";
        /** publicAccess column */
        public static final String PUBLICACCESS = "publicAccess";
        /** isEnabled column */
        public static final String ISENABLED = "isEnabled";
        /** isDefault column */
        public static final String ISDEFAULT = "isDefault";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("userId");
            list.add("groupId");
            list.add("entityType");
            list.add("entityId");
            list.add("publicAccess");
            list.add("isEnabled");
            list.add("isDefault");

            return list;
        }
    }

    /** Acl FK class */
    public static class FK {
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName)
    {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("userId".equalsIgnoreCase(attributeName))
            return userId;
        if ("groupId".equalsIgnoreCase(attributeName))
            return groupId;
        if ("entityType".equalsIgnoreCase(attributeName))
            return entityType;
        if ("entityId".equalsIgnoreCase(attributeName))
            return entityId;
        if ("publicAccess".equalsIgnoreCase(attributeName))
            return publicAccess;
        if ("isEnabled".equalsIgnoreCase(attributeName))
            return isEnabled;
        if ("isDefault".equalsIgnoreCase(attributeName))
            return isDefault;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue)
    {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long) attributeValue;
        if ("userId".equalsIgnoreCase(attributeName))
            userId = (String) attributeValue;
        if ("groupId".equalsIgnoreCase(attributeName))
            groupId = (String) attributeValue;
        if ("entityType".equalsIgnoreCase(attributeName))
            entityType = (String) attributeValue;
        if ("entityId".equalsIgnoreCase(attributeName))
            entityId = (String) attributeValue;
        if ("publicAccess".equalsIgnoreCase(attributeName))
            publicAccess = (String) attributeValue;
        if ("isEnabled".equalsIgnoreCase(attributeName))
            isEnabled = (String) attributeValue;
        if ("isDefault".equalsIgnoreCase(attributeName))
            isDefault = (String) attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** userId private attribute */
    private String userId;

    /** groupId private attribute */
    private String groupId;

    /** entityType private attribute */
    private String entityType;

    /** entityId private attribute */
    private String entityId;

    /** publicAccess private attribute */
    private String publicAccess;

    /** isEnabled private attribute */
    private String isEnabled;

    /** isDefault private attribute */
    private String isDefault;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    public synchronized static List<String> getPKFieldList()
    {
        if (pkFieldList == null)
        {
            pkFieldList = new ArrayList<String>();
            pkFieldList.add("id");
        }

        return pkFieldList;
    }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
    public static String getPKFieldListAsString()
    {
        StringBuffer buffer = new StringBuffer();

        for (int i = 0; i < getPKFieldList().size(); i++)
        {
            if (i != 0)
                buffer.append(",");

            buffer.append(getPKFieldList().get(i));
        }

        return buffer.toString();
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
    @Override
    public String getAttributeAsString(String attributeName)
    {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else
        {
            return value.toString().trim();
        }
    }

    // Constructors

    /**
     * default constructor
     */
    public Acl()
    {}

    /**
     * full constructor
     *
     * @param userId
     * @param groupId
     * @param entityType
     * @param entityId
     * @param publicAccess
     * @param isEnabled
     * @param isDefault
     */
    public Acl(String userId, String groupId, String entityType, String entityId, String publicAccess, String isEnabled,
            String isDefault)
    {
        this.userId = userId;
        this.groupId = groupId;
        this.entityType = entityType;
        this.entityId = entityId;
        this.publicAccess = publicAccess;
        this.isEnabled = isEnabled;
        this.isDefault = isDefault;
    }

    // Property accessors

    /**
     * id getter method
     *
     * @return id method
     */
    public Long getId()
    {
        return this.id;
    }

    /**
     * id setter method
     *
     * @param id
     * @return Acl modified instance
     */
    public Acl setId(Long id)
    {
        this.id = id;

        return this;
    }

    /**
     * userId getter method
     *
     * @return userId method
     */
    public String getUserId()
    {
        return this.userId;
    }

    /**
     * userId setter method
     *
     * @param userId
     * @return Acl modified instance
     */
    public Acl setUserId(String userId)
    {
        this.userId = userId;

        return this;
    }

    /**
     * groupId getter method
     *
     * @return groupId method
     */
    public String getGroupId()
    {
        return this.groupId;
    }

    /**
     * groupId setter method
     *
     * @param groupId
     * @return Acl modified instance
     */
    public Acl setGroupId(String groupId)
    {
        this.groupId = groupId;

        return this;
    }

    /**
     * entityType getter method
     *
     * @return entityType method
     */
    public String getEntityType()
    {
        return this.entityType;
    }

    /**
     * entityType setter method
     *
     * @param entityType
     * @return Acl modified instance
     */
    public Acl setEntityType(String entityType)
    {
        this.entityType = entityType;

        return this;
    }

    /**
     * entityId getter method
     *
     * @return entityId method
     */
    public String getEntityId()
    {
        return this.entityId;
    }

    /**
     * entityId setter method
     *
     * @param entityId
     * @return Acl modified instance
     */
    public Acl setEntityId(String entityId)
    {
        this.entityId = entityId;

        return this;
    }

    /**
     * publicAccess getter method
     *
     * @return publicAccess method
     */
    public String getPublicAccess()
    {
        return this.publicAccess;
    }

    /**
     * publicAccess setter method
     *
     * @param publicAccess
     * @return Acl modified instance
     */
    public Acl setPublicAccess(String publicAccess)
    {
        this.publicAccess = publicAccess;

        return this;
    }

    /**
     * isEnabled getter method
     *
     * @return isEnabled method
     */
    public String getIsEnabled()
    {
        return this.isEnabled;
    }

    /**
     * isEnabled setter method
     *
     * @param isEnabled
     * @return Acl modified instance
     */
    public Acl setIsEnabled(String isEnabled)
    {
        this.isEnabled = isEnabled;

        return this;
    }

    /**
     * isDefault getter method
     *
     * @return isDefault method
     */
    public String getIsDefault()
    {
        return this.isDefault;
    }

    /**
     * isDefault setter method
     *
     * @param isDefault
     * @return Acl modified instance
     */
    public Acl setIsDefault(String isDefault)
    {
        this.isDefault = isDefault;

        return this;
    }

    /**
     * Creates a String representation of the Acl object
     *
     * @return the compiled String
     */
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");
        buffer.append("userId").append("='").append(getUserId()).append("' ");
        buffer.append("groupId").append("='").append(getGroupId()).append("' ");
        buffer.append("entityType").append("='").append(getEntityType()).append("' ");
        buffer.append("entityId").append("='").append(getEntityId()).append("' ");
        buffer.append("publicAccess").append("='").append(getPublicAccess()).append("' ");
        buffer.append("isEnabled").append("='").append(getIsEnabled()).append("' ");
        buffer.append("isDefault").append("='").append(getIsDefault()).append("' ");
        buffer.append("]");

        return buffer.toString();
    }

    /**
     * Compares the String representation of the Acl object
     *
     * @param other
     *            The object to compare to
     * @return true of the objects are equal
     */
    public boolean equals(Acl other)
    {
        return this.toString().equals(other.toString());
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue)
    {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("userId".equalsIgnoreCase(attributeName))
            this.userId = attributeValue;

        if ("groupId".equalsIgnoreCase(attributeName))
            this.groupId = attributeValue;

        if ("entityType".equalsIgnoreCase(attributeName))
            this.entityType = attributeValue;

        if ("entityId".equalsIgnoreCase(attributeName))
            this.entityId = attributeValue;

        if ("publicAccess".equalsIgnoreCase(attributeName))
            this.publicAccess = attributeValue;

        if ("isEnabled".equalsIgnoreCase(attributeName))
            this.isEnabled = attributeValue;

        if ("isDefault".equalsIgnoreCase(attributeName))
            this.isDefault = attributeValue;

    }

}
